@@ -3,9 +3,9 @@ from typing import Dict, List, Optional
 
 import torch
 import torch.nn as nn
+from torch import Tensor
 from torch.nn.functional import mse_loss
 from torch.optim import Adam
-from torch.tensor import Tensor
 
 from ai_traineree import DEVICE
 from ai_traineree.agents import AgentBase
@@ -15,8 +15,7 @@ from ai_traineree.buffers.buffer_factory import BufferFactory
 from ai_traineree.loggers import DataLogger
 from ai_traineree.networks.bodies import ActorBody, CriticBody
 from ai_traineree.noise import GaussianNoise
-from ai_traineree.types import AgentState, BufferState, NetworkState
-from ai_traineree.types.primitive import ActionType, DoneType, ObsType, RewardType
+from ai_traineree.types import ActionType, AgentState, BufferState, DoneType, NetworkState, ObsType, RewardType
 from ai_traineree.utils import to_numbers_seq, to_tensor
 
 
