@@ -15,8 +15,7 @@ from ai_traineree.buffers.buffer_factory import BufferFactory
 from ai_traineree.loggers import DataLogger
 from ai_traineree.networks.bodies import ActorBody
 from ai_traineree.policies import MultivariateGaussianPolicy, MultivariateGaussianPolicySimple
-from ai_traineree.types.primitive import ActionType, DoneType, ObsType, RewardType
-from ai_traineree.types.state import AgentState, BufferState, NetworkState
+from ai_traineree.types import ActionType, AgentState, BufferState, DoneType, NetworkState, ObsType, RewardType
 from ai_traineree.utils import to_numbers_seq, to_tensor
 
 
