@@ -1,10 +1,11 @@
 # import torch
 from typing import Dict, List, Sequence, Union
 
-StateType = List[float]
+ObsType = ObservationType = Union[List[int], List[float]]
+StateType = Union[int, List[float]]
 ActionType = Union[int, List]
 DoneType = bool
 RewardType = Union[int, float]
 
 HyperparameterType = Dict[str, str]
-FeatureType = Union[Sequence[int], int]
+FeatureType = Sequence[int]
