@@ -28,7 +28,7 @@ config = {
 agent = Agent(task.obs_size, task.action_size, hidden_layers=(100, 100, 50), **config)
 env_runner = EnvRunner(task, agent, data_logger=data_logger)
 # env_runner.interact_episode(0, render=True)
-scores = env_runner.run(80, 2000, eps_decay=0.99, force_new=True, checkpoint_every=20)
+scores = env_runner.run(80, 2000, eps_decay=0.97, eps_end=0.05, force_new=True, checkpoint_every=200)
 env_runner.interact_episode(0, render=True)
 
 data_logger.close()
